@@ -2,6 +2,8 @@ import time
 import unittest
 
 from django.test.client import Client
+from session_security.utils import set_last_activity
+from datetime import datetime, timedelta
 
 
 class MiddlewareTestCase(unittest.TestCase):
@@ -16,6 +18,14 @@ class MiddlewareTestCase(unittest.TestCase):
         response = self.client.get('/admin/')
         self.assertFalse('_auth_user_id' in self.client.session)
 
+    def test_last_activity_in_future(self):
+        self.client.login(username='test', password='test')
+        now = datetime.now()
+        future = now + timedelta(0, 30)
+        set_last_activity(self.client.session, future)
+        response = self.client.get('/admin/')
+        self.assertTrue('_auth_user_id' in self.client.session)
+
     def test_non_javascript_browse_no_logout(self):
         self.client.login(username='test', password='test')
         response = self.client.get('/admin/')
